@@ -1,36 +1,12 @@
-# Copyright (C) 2002-2014 by Barry A. Warsaw
-#
-# This file is part of flufl.bounce
-#
-# flufl.bounce is free software: you can redistribute it and/or modify it
-# under the terms of the GNU Lesser General Public License as published by the
-# Free Software Foundation, version 3 of the License.
-#
-# flufl.bounce is distributed in the hope that it will be useful, but WITHOUT
-# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
-# for more details.
-#
-# You should have received a copy of the GNU Lesser General Public License
-# along with flufl.bounce.  If not, see <http://www.gnu.org/licenses/>.
-
 """Recognizes (some) Microsoft Exchange formats."""
 
-from __future__ import absolute_import, unicode_literals
-
-__metaclass__ = type
-__all__ = [
-    'Exchange',
-    ]
-
-
 import re
 
 from email.iterators import body_line_iterator
-from zope.interface import implementer
-
 from flufl.bounce.interfaces import (
     IBounceDetector, NoFailures, NoTemporaryFailures)
+from public import public
+from zope.interface import implementer
 
 
 scre = re.compile('did not reach the following recipient')
@@ -39,7 +15,7 @@ a1cre = re.compile('SMTP=(?P<addr>[^;]+); on ')
 a2cre = re.compile('(?P<addr>[^ ]+) on ')
 
 
-
+@public
 @implementer(IBounceDetector)
 class Exchange:
     """Recognizes (some) Microsoft Exchange formats."""
