@@ -1,38 +1,14 @@
-# Copyright (C) 1998-2014 by Barry A. Warsaw
-#
-# This file is part of flufl.bounce
-#
-# flufl.bounce is free software: you can redistribute it and/or modify it
-# under the terms of the GNU Lesser General Public License as published by the
-# Free Software Foundation, version 3 of the License.
-#
-# flufl.bounce is distributed in the hope that it will be useful, but WITHOUT
-# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
-# for more details.
-#
-# You should have received a copy of the GNU Lesser General Public License
-# along with flufl.bounce.  If not, see <http://www.gnu.org/licenses/>.
-
 """Yahoo! has its own weird format for bounces."""
 
-from __future__ import absolute_import, unicode_literals
-
-__metaclass__ = type
-__all__ = [
-    'Yahoo',
-    ]
-
-
 import re
 
 from email.iterators import body_line_iterator
 from email.utils import parseaddr
 from enum import Enum
-from zope.interface import implementer
-
 from flufl.bounce.interfaces import (
     IBounceDetector, NoFailures, NoTemporaryFailures)
+from public import public
+from zope.interface import implementer
 
 
 tcre = (re.compile(r'message\s+from\s+yahoo\.\S+', re.IGNORECASE),
@@ -43,6 +19,7 @@ tcre = (re.compile(r'message\s+from\s+yahoo\.\S+', re.IGNORECASE),
 acre = re.compile(r'<(?P<addr>[^>]*)>:')
 ecre = (re.compile(r'--- Original message follows'),
         re.compile(r'--- Below this line is a copy of the message'),
+        re.compile(r'---------- Forwarded message ----------'),
         )
 
 
@@ -52,7 +29,7 @@ class _ParseState(Enum):
     all_done = 2
 
 
-
+@public
 @implementer(IBounceDetector)
 class Yahoo:
     """Yahoo! bounce detection."""
